@@ -31,7 +31,7 @@
 #include "nautilus-clipboard.h"
 #include "nautilus-file-utilities.h"
 
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <gtk/gtkclipboard.h>
 #include <gtk/gtkstock.h>
 #include <gtk/gtkinvisible.h>
@@ -66,7 +66,7 @@ struct _TargetCallbackData {
 static void
 cut_callback (gpointer target)
 {
-	g_return_if_fail (target != NULL);
+	g_assert (target != NULL);
 
 	g_signal_emit_by_name (target, "cut-clipboard");
 }
@@ -74,7 +74,7 @@ cut_callback (gpointer target)
 static void
 copy_callback (gpointer target)
 {
-	g_return_if_fail (target != NULL);
+	g_assert (target != NULL);
 
 	g_signal_emit_by_name (target, "copy-clipboard");
 }
@@ -82,7 +82,7 @@ copy_callback (gpointer target)
 static void
 paste_callback (gpointer target)
 {
-	g_return_if_fail (target != NULL);
+	g_assert (target != NULL);
 
 	g_signal_emit_by_name (target, "paste-clipboard");
 }
@@ -93,7 +93,7 @@ editable_select_all_callback (gpointer target)
 	GtkEditable *editable;
 
 	editable = GTK_EDITABLE (target);
-	g_return_if_fail (editable != NULL);
+	g_assert (editable != NULL);
 
 	gtk_editable_set_position (editable, -1);
 	gtk_editable_select_region (editable, 0, -1);
@@ -102,7 +102,7 @@ editable_select_all_callback (gpointer target)
 static void
 text_view_select_all_callback (gpointer target)
 {
-	g_return_if_fail (GTK_IS_TEXT_VIEW (target));
+	g_assert (GTK_IS_TEXT_VIEW (target));
 
 	g_signal_emit_by_name (target, "select-all", TRUE);
 }
@@ -134,10 +134,10 @@ action_select_all_callback (GtkAction *action,
 {
 	TargetCallbackData *target_data;
 
-	g_return_if_fail (callback_data != NULL);
+	g_assert (callback_data != NULL);
 
 	target_data = g_object_get_data (callback_data, "Nautilus:clipboard_target_data");
-	g_return_if_fail (target_data != NULL);
+	g_assert (target_data != NULL);
 
 	target_data->select_all_callback (callback_data);
 }
@@ -393,7 +393,7 @@ selection_changed_callback (GtkWidget *widget,
 	g_assert (target_data != NULL);
 
 	editable = GTK_EDITABLE (widget);
-	g_return_if_fail (editable != NULL);
+	g_assert (editable != NULL);
 
 	if (gtk_editable_get_selection_bounds (editable, &start, &end) && start != end) {
 		set_clipboard_menu_items_sensitive (target_data->action_group);
@@ -437,22 +437,22 @@ target_data_free (TargetCallbackData *target_data)
 }
 
 static const GtkActionEntry clipboard_entries[] = {
-  { "Cut", GTK_STOCK_CUT,                  /* name, stock id */
-    NULL, NULL,                /* label, accelerator */
-    N_("Cut the selected text to the clipboard"),                   /* tooltip */ 
-    G_CALLBACK (action_cut_callback) },
-  { "Copy", GTK_STOCK_COPY,                  /* name, stock id */
-    NULL, NULL,                /* label, accelerator */
-    N_("Copy the selected text to the clipboard"),                   /* tooltip */ 
-    G_CALLBACK (action_copy_callback) },
-  { "Paste", GTK_STOCK_PASTE,                  /* name, stock id */
-    NULL, NULL,                /* label, accelerator */
-    N_("Paste the text stored on the clipboard"),                   /* tooltip */ 
-    G_CALLBACK (action_paste_callback) },
-  { "Select All", NULL,                  /* name, stock id */
-    N_("Select _All"), "<control>A",                /* label, accelerator */
-    N_("Select all the text in a text field"),                   /* tooltip */ 
-    G_CALLBACK (action_select_all_callback) },
+  /* name, stock id */      { "Cut", GTK_STOCK_CUT,
+  /* label, accelerator */    NULL, NULL,
+  /* tooltip */               N_("Cut the selected text to the clipboard"),
+                              G_CALLBACK (action_cut_callback) },
+  /* name, stock id */      { "Copy", GTK_STOCK_COPY,
+  /* label, accelerator */    NULL, NULL,
+  /* tooltip */               N_("Copy the selected text to the clipboard"),
+                              G_CALLBACK (action_copy_callback) },
+  /* name, stock id */      { "Paste", GTK_STOCK_PASTE,
+  /* label, accelerator */    NULL, NULL,
+  /* tooltip */               N_("Paste the text stored on the clipboard"),
+                              G_CALLBACK (action_paste_callback) },
+  /* name, stock id */      { "Select All", NULL,
+  /* label, accelerator */    N_("Select _All"), "<control>A",
+  /* tooltip */               N_("Select all the text in a text field"),
+                              G_CALLBACK (action_select_all_callback) },
 };
 
 static TargetCallbackData *
