@@ -36,12 +36,7 @@
 #include <gtk/gtktreesortable.h>
 #include <glib/gi18n.h>
 #include <libnautilus-private/nautilus-dnd.h>
-
-#if GLIB_CHECK_VERSION (2, 13, 0)
 #include <glib/gsequence.h>
-#else
-#include <gsequence/gsequence.h>
-#endif
 
 enum {
 	SUBDIRECTORY_UNLOADED,
@@ -292,8 +287,7 @@ fm_list_model_get_value (GtkTreeModel *tree_model, GtkTreeIter *iter, int column
 			zoom_level = fm_list_model_get_zoom_level_from_column_id (column);
 			icon_size = nautilus_get_icon_size_for_zoom_level (zoom_level);
 
-			flags = NAUTILUS_FILE_ICON_FLAGS_USE_THUMBNAILS |
-				NAUTILUS_FILE_ICON_FLAGS_FORCE_THUMBNAIL_SIZE;
+			flags = NAUTILUS_FILE_ICON_FLAGS_USE_THUMBNAILS;
 			if (model->details->drag_view != NULL) {
 				GtkTreePath *path_a, *path_b;
 				
