@@ -34,7 +34,6 @@
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-gnome-extensions.h>
-#include <libnautilus-private/nautilus-icon-factory.h>
 #include <libnautilus-private/nautilus-undo-signal-handlers.h>
 #include <gtk/gtkenums.h>
 #include <gtk/gtkhbbox.h>
@@ -42,7 +41,6 @@
 #include <libgnomeui/gnome-help.h>
 #include <glade/glade.h>
 
-
 /* Static variables to keep track of window state. If there were
  * more than one bookmark-editing window, these would be struct or
  * class fields. 
@@ -65,6 +63,7 @@ static int		     uri_field_changed_signal_id;
 static int		     row_changed_signal_id;
 static int		     row_deleted_signal_id;
 static int                   row_activated_signal_id;
+static int                   button_pressed_signal_id;
 static int                   key_pressed_signal_id;
 static int                   jump_button_signal_id;
 static NautilusApplication  *application;
@@ -94,6 +93,9 @@ static void	on_row_activated			    (GtkTreeView	  *view,
 							     GtkTreePath	  *path,
                                                              GtkTreeViewColumn    *column,
 							     gpointer		   user_data);
+static gboolean	on_button_pressed                           (GtkTreeView	  *view,
+                                                             GdkEventButton       *event,
+							     gpointer		   user_data);
 static gboolean	on_key_pressed                              (GtkTreeView	  *view,
                                                              GdkEventKey          *event,
 							     gpointer		   user_data);
@@ -115,6 +117,7 @@ static void     on_window_destroy_event                     (GtkWidget
 static void     repopulate                                  (void);
 static void     set_up_close_accelerator                    (GtkWidget            *window);
 static void	open_selected_bookmark 			    (gpointer   user_data, GdkScreen *screen);
+static void	update_bookmark_from_text		    (void);
 
 /* We store a pointer to the bookmark in a column so when an item is moved
    with DnD we know which item it is. However we have to be careful to keep
@@ -346,6 +349,9 @@ create_bookmarks_window (NautilusBookmarkList *list, GObject *undo_manager_sourc
         row_activated_signal_id =
                 g_signal_connect (bookmark_list_widget, "row_activated",
                                   G_CALLBACK (on_row_activated), undo_manager_source);
+        button_pressed_signal_id =
+                g_signal_connect (bookmark_list_widget, "button_press_event",
+                                  G_CALLBACK (on_button_pressed), NULL);
         key_pressed_signal_id =
                 g_signal_connect (bookmark_list_widget, "key_press_event",
                                   G_CALLBACK (on_key_pressed), NULL);
@@ -385,11 +391,6 @@ create_bookmarks_window (NautilusBookmarkList *list, GObject *undo_manager_sourc
 		g_signal_connect (jump_button, "clicked",
 				  G_CALLBACK (on_jump_button_clicked), undo_manager_source);
 
-	/* Register to find out about icon theme changes */
-	g_signal_connect_object (nautilus_icon_factory_get (), "icons_changed",
-				 G_CALLBACK (repopulate), window,
-				 G_CONNECT_SWAPPED);
-                      	    
 	gtk_tree_selection_set_mode (bookmark_selection, GTK_SELECTION_BROWSE);
 	
 	/* Fill in list widget with bookmarks, must be after signals are wired up. */
@@ -550,7 +551,7 @@ open_selected_bookmark (gpointer user_data, GdkScreen *screen)
 {
 	NautilusBookmark *selected;
 	NautilusWindow *window;
-	char *uri = NULL;
+	GFile *location;
 	
 	selected = get_selected_bookmark ();
 
@@ -558,36 +559,35 @@ open_selected_bookmark (gpointer user_data, GdkScreen *screen)
 		return;
 	}
 
-	uri = nautilus_bookmark_get_uri (selected);
-
-	if (!uri) { 
+	location = nautilus_bookmark_get_location (selected);
+	if (location == NULL) { 
 		return;
 	}
 
 	if (NAUTILUS_IS_NAVIGATION_WINDOW (user_data)) {
-		nautilus_window_go_to (NAUTILUS_WINDOW (user_data), uri);
+		nautilus_window_go_to (NAUTILUS_WINDOW (user_data), location);
 	} else if (NAUTILUS_IS_SPATIAL_WINDOW (user_data)) {
 		window = nautilus_application_present_spatial_window (application, 
 								      NULL,
 								      NULL,
-								      uri,
+								      location,
 								      screen);
 	} else { /* window that opened bookmarks window has been closed */
 		if (parent_is_browser_window || eel_preferences_get_boolean (NAUTILUS_PREFERENCES_ALWAYS_USE_BROWSER)) {
 			window = nautilus_application_create_navigation_window (application, 
 										NULL,
 										screen);
-			nautilus_window_go_to (window, uri);
+			nautilus_window_go_to (window, location);
 		} else {
 			window = nautilus_application_present_spatial_window (application, 
 									      NULL,
 									      NULL,
-									      uri,
+									      location,
 									      screen);
 		}
 	}
 
-	g_free (uri);
+	g_object_unref (location);
 }
 
 static void
@@ -693,6 +693,28 @@ on_row_changed (GtkListStore *store,
 	}
 }
 
+/* The update_bookmark_from_text() calls in the
+ * on_button_pressed() and on_key_pressed() handlers
+ * of the tree view are a hack.
+ *
+ * The purpose is to track selection changes to the view
+ * and write the text fields back before the selection
+ * actually changed.
+ *
+ * Note that the focus-out event of the text entries is emitted
+ * after the selection changed, else this would not not be neccessary.
+ */
+
+static gboolean
+on_button_pressed (GtkTreeView *view,
+		   GdkEventButton *event,
+		   gpointer user_data)
+{
+	update_bookmark_from_text ();
+
+	return FALSE;
+}
+
 static gboolean
 on_key_pressed (GtkTreeView *view,
                 GdkEventKey *event,
@@ -703,6 +725,8 @@ on_key_pressed (GtkTreeView *view,
                 return TRUE;
         }
 
+	update_bookmark_from_text ();
+
         return FALSE;
 }
 
@@ -783,15 +807,17 @@ update_bookmark_from_text (void)
 		GdkPixbuf *pixbuf;
 		guint selected_row;
 		GtkTreeIter iter;
+		GFile *location;
 
 		g_assert (GTK_IS_ENTRY (name_field));
 		g_assert (GTK_IS_ENTRY (uri_field));
 
-		bookmark = nautilus_bookmark_new
-			(gtk_entry_get_text (GTK_ENTRY (uri_field)),
-			 gtk_entry_get_text (GTK_ENTRY (name_field)));
-
-		nautilus_bookmark_set_has_custom_name (bookmark, name_text_changed);
+		location = g_file_new_for_uri (gtk_entry_get_text (GTK_ENTRY (uri_field)));
+		
+		bookmark = nautilus_bookmark_new_with_icon (location, gtk_entry_get_text (GTK_ENTRY (name_field)),
+							    name_text_changed, NULL);
+		
+		g_object_unref (location);
 
 		selected_row = get_selected_row ();
 
@@ -901,21 +927,27 @@ static void
 on_window_destroy_event (GtkWidget *widget,
 		      	 gpointer user_data)
 {
-	g_message ("destroying bookmarks window");
+	g_object_unref (bookmark_list_store);
+	g_object_unref (bookmark_empty_list_store);
 	g_source_remove_by_user_data (widget);
 }
 
 static void
 repopulate (void)
 {
-	guint index;
+	NautilusBookmark *selected;
 	GtkListStore *store;
-	
+	GtkTreePath *path;
+	GtkTreeRowReference *reference;
+	guint index;
+
 	g_assert (GTK_IS_TREE_VIEW (bookmark_list_widget));
 	g_assert (NAUTILUS_IS_BOOKMARK_LIST (bookmarks));
 	
 	store = GTK_LIST_STORE (bookmark_list_store);
 
+	selected = get_selected_bookmark ();
+
 	g_signal_handler_block (bookmark_selection,
 				selection_changed_id);
 	g_signal_handler_block (bookmark_list_store,
@@ -924,6 +956,8 @@ repopulate (void)
                                 row_activated_signal_id);
         g_signal_handler_block (bookmark_list_widget,
                                 key_pressed_signal_id);
+        g_signal_handler_block (bookmark_list_widget,
+                                button_pressed_signal_id);
 
 	gtk_list_store_clear (store);
 	
@@ -931,6 +965,8 @@ repopulate (void)
 				  row_activated_signal_id);
         g_signal_handler_unblock (bookmark_list_widget,
                                   key_pressed_signal_id);
+        g_signal_handler_unblock (bookmark_list_widget,
+                                  button_pressed_signal_id);
 	g_signal_handler_unblock (bookmark_list_store,
 				  row_deleted_signal_id);
 	g_signal_handler_unblock (bookmark_selection,
@@ -939,6 +975,8 @@ repopulate (void)
 	/* Fill the list in with the bookmark names. */
 	g_signal_handler_block (store, row_changed_signal_id);
 
+	reference = NULL;
+
 	for (index = 0; index < nautilus_bookmark_list_length (bookmarks); ++index) {
 		NautilusBookmark *bookmark;
 		char             *bookmark_name;
@@ -956,13 +994,41 @@ repopulate (void)
 				    BOOKMARK_LIST_COLUMN_BOOKMARK, bookmark,
 				    BOOKMARK_LIST_COLUMN_STYLE, PANGO_STYLE_NORMAL,
 				    -1);
-		
+
+		if (bookmark == selected) {
+			/* save old selection */
+			GtkTreePath *path;
+
+			path = gtk_tree_model_get_path (GTK_TREE_MODEL (store), &iter);
+			reference = gtk_tree_row_reference_new (GTK_TREE_MODEL (store), path);
+			gtk_tree_path_free (path);
+		}
+
 		g_free (bookmark_name);
 		g_object_unref (bookmark_pixbuf);
 		
 	}
 	g_signal_handler_unblock (store, row_changed_signal_id);
 
+	if (reference != NULL) {
+		/* restore old selection */
+
+		/* bookmarks_set_empty() will call the selection change handler,
+ 		 * so we block it here in case of selection change.
+ 		 */
+		g_signal_handler_block (bookmark_selection, selection_changed_id);
+
+		g_assert (index != 0);
+		g_assert (gtk_tree_row_reference_valid (reference));
+
+		path = gtk_tree_row_reference_get_path (reference);
+		gtk_tree_selection_select_path (bookmark_selection, path);
+		gtk_tree_row_reference_free (reference);
+		gtk_tree_path_free (path);
+
+		g_signal_handler_unblock (bookmark_selection, selection_changed_id);
+	}
+
 	bookmarks_set_empty (index == 0);	  
 }
 
